*
* ARGS.CMD
*
* Shows how the argument parser works
* This just takes arguments and puts them on the screen.
* PereLine's arguments are substituted by placing an '&' (ampersand)
* in front of them.  When PereLine sees something like &DATE it fills
* in the information (in this case today's date) before the command
* is processed.  Thus, it looks like the date was orginally in the
* line.  For example, when the scripts says:
*
*       Display &DATE
*
* PereLine really sees:
*
*       Display 03/15/91
*
* (or whatever the current date is)
*
* You can use this concept for a lot of tricky things.  Try it out.
*

*
* If no arguments are passed in then set some up ...
*
If &ARGCOUNT = 0
	args arg1 arg2 arg3 arg4 arg5 arg6 arg7 arg8 arg9 arg10
EndIf

*
* Clear the screen and display the arguments
*  (either the ones they passed in or the ones we set up above)
*
Clear
Display
Parsed Arguments:
	arg1 = &1
	arg2 = &2
	arg3 = &3
	arg4 = &4
	arg5 = &5
	arg6 = &6
	arg7 = &7
	arg8 = &8
	arg9 = &9
	arg0 = &0
EndDisplay

*
* Let them read the screen before continuing ...
*
AnyKey Local Press Any Key to Continue

*
* Display all of PereLine's built in arguments.
* The reason the one's in the beginning of the line have backslashes
* in front of them is so that they will not be substituted.  For example,
* we really want it to say '&ARGCOUNT' instead of putting in the actual
* number of arguments passed into the script.
*
Clear
Display
    \&ARGCOUNT   = '&ARGCOUNT'
    \&PORT       = '&PORT'       \&PROTOCOL   = '&PROTOCOL'
    \&XTERNAL    = '&XTERNAL'    \&USER       = '&USER' 
    \&ISCONNECT  = '&ISCONNECT'  \&ISRETRY    = '&ISRETRY'
    \&ISPRINT    = '&ISPRINT'    \&ISBATCH    = '&ISBATCH'
    \&ISDIRECT   = '&ISDIRECT'   \&ISTRANSFER = '&ISTRANSFER'
    \&TIME       = '&TIME'       \&DATE = '&DATE'
    \&LDATE      = '&LDATE'
    \&DISK       = '&DISK'
    \&DIRECTORY  = '&DIRECTORY'
    \&SYSTEM     = '&SYSTEM'
    \&DOWNLOAD   = '&DOWNLOAD'
    \&EMULATION  = '&EMULATION'
    \&ANSWERBACK = '&ANSWERBACK'
    \&ROW        = '&ROW'        \&COL = '&COL'
    \&WIDTH      = '&WIDTH'   \&LENGTH = '&LENGTH'
    \&ADAPTER    = '&ADAPTER'  \&VIDEO = '&VIDEO'   \&MONITOR = '&MONITOR'
    \&TOTMEM     = '&TOTMEM' \&FREEMEM = '&FREEMEM'
    The Time is: &HOUR:&MIN:&SEC &MONTH/&DAY/&YEAR
EndDisplay

*
* Let them read the screen before continuing
*
AnyKey Local "Press Any Key to Continue ..."   // This is a comment

*
* Display all of PereLine's functions.  The backslashes are used here
* as well.  Any of the & variables or functions can be 'escaped' using
* a backslash.
*
Clear
Display
    \&FREEDISK(0)                = &FREEDISK(0)
    \&TOTDISK(0)                 = &TOTDISK(0)
    \&FREEDISK(3)                = &FREEDISK(3)
    \&TOTDISK(3)                 = &TOTDISK(3)
    \&FREEDISK(4)                = &FREEDISK(4)
    \&TOTDISK(4)                 = &TOTDISK(4)
    \&FILEDATE(PED.EXE)          = &FILEDATE( PED.EXE )
    \&FILESIZE(PED.EXE)          = &FILESIZE( PED.EXE )
    \&LOWER(SHOULD BE LOWER)     = &LOWER(SHOULD BE LOWER)
    \&UPPER(should be upper)     = &UPPER(should be upper)
    \&ENVIRON(TMP)               = &ENVIRON( TMP )
    \&PHONENUMBER(PereLine)      = &PHONENUMBER(PereLine)
    \&PHONENUMBER(No One)        = &PHONENUMBER(No One)
    \&LEFT(3 abcdefghijklmnop)   = &LEFT(3 abcdefghijklmnop)  (abc)
    \&RIGHT(3 abcdefghijklmnop)  = &RIGHT(3 abcdefghijklmnop) (nop)
    \&MID(1 3 abcdefghijklmnop)  = &MID(1 3 abcdefghijklmnop) (abc)
    \&MID(3 4 abcdefghijklmnop)  = &MID(3 4 abcdefghijklmnop) (cdef)
   
    \&STRLEN(This is a test)      = &STRLEN(This is a test) (14)
    \&UPPER(\&FILEDATE(PED.EXE))  = &UPPER(&FILEDATE(PED.EXE))
    \&LOWER(\&FILEDATE(PED.EXE))  = &LOWER(&FILEDATE(PED.EXE))
    \&COMMA(\&TOTMEM)             = &COMMA(&TOTMEM)
EndDisplay

*
* Let them read the screen before continuing
*
AnyKey Local "Press Any Key to Continue ..."

*
* This one shows how you can use quotes (") around strings if you want
* to make it look prettier.  PereLine basically ignores the quotes
* unless there is a need for them.  Extra spaces are also ignored.
*
Clear
Display
    \&FREEDISK(0)                = &FREEDISK(0)
    \&TOTDISK(0)                 = &TOTDISK(0)
    \&FREEDISK(3)                = &FREEDISK(3)
    \&TOTDISK(3)                 = &TOTDISK(3)
    \&FREEDISK(4)                = &FREEDISK(4)
    \&TOTDISK(4)                 = &TOTDISK(4)
    \&FILEDATE(PED.EXE)          = &FILEDATE( PED.EXE )
    \&FILESIZE(PED.EXE)          = &FILESIZE( PED.EXE )
    \&LOWER(SHOULD BE LOWER)     = &LOWER("SHOULD BE LOWER")
    \&UPPER(should be upper)     = &UPPER("should be upper")
    \&ENVIRON(TMP)               = &ENVIRON( TMP )
    \&PHONENUMBER(PereLine)      = &PHONENUMBER("PereLine")
    \&PHONENUMBER(No One)        = &PHONENUMBER(No One)
    \&LEFT(3 abcdefghijklmnop)   = &LEFT(3 "abcdefghijklmnop")  (abc)
    \&RIGHT(3 abcdefghijklmnop)  = &RIGHT(3 "abcdefghijklmnop") (nop)
    \&MID(1 3 abcdefghijklmnop)  = &MID(1 3 "abcdefghijklmnop") (abc)
    \&MID(3 4 abcdefghijklmnop)  = &MID(3 4 "abcdefghijklmnop") (cdef)
   
    \&STRLEN(This is a test)     = &STRLEN("This is a test") (14)
    \&UPPER(\&FILEDATE(PED.EXE))  = &UPPER(&FILEDATE("PED.EXE"))
    \&LOWER(\&FILEDATE(PED.EXE))  = &LOWER(&FILEDATE("PED.EXE"))
    \&COMMA(\&TOTMEM)             = &COMMA(&TOTMEM)
EndDisplay

*
* Let them read the screen before continuing
*
AnyKey Local "Press Any Key to Continue ..."

*
* Define a bunch of variables with names.  The names here are not very
* creative, but they serve their purpose.
*
Define V1 V2 V3 V4 V5 V11 V12 V13 V14 V15

Assign V1  "This is V1"
Assign V2  "This is V2"
Assign V3  "This is V3"
Assign V4  "This is V4"
Assign V5  "This is V5"
Assign V11 "This is V11"
Assign V12 "This is V12"
Assign V13 "This is V13"
Assign V14 "This is V14"
Assign V15 "This is V15"

*
* Display the results ...
* Note that the date is substituted just like it was with the built in
* variables.  The last variable display (V15) has some stuff tacked on
* the end of it.  The &V15 is still substituted.  So, the result is:
*
*  'This is V15with stuff after it'
*
Clear
Display


	These are the user variables defined:

	V1 = &v1
	V2 = &v2
	V3 = &v3
	V4 = &v4
	V5 = &v5

	V11 = &v11
	V12 = &v12
	V13 = &v13
	V14 = &v14
	V15 = &V15

	V1 = &V1with stuff after it
EndDisplay

*
* Let them read the screen before continuing
*
AnyKey Local "Variable Test all done press any key ..."

